' //////////////////////////////////////////////////////
' AUTHOR: Coley
' LAST MODIFIED: 23.06.08
' VERSION 1
' COMMENTS: Routine for checking Hardware configurations
'           of various Propeller based boards.             
' //////////////////////////////////////////////////////
'
'  Power on harware configurations for target boards
'
'                      Pin Number
'
'            00000000001111111111222222222233
'            01234567890123456789012345678901
'
'                                    vdac
' Hybrid     000000001111111100000000OOOO1111
'
'                        vdac
' Demoboard  000000000000OOOO0000000011110111
'
'                                    vdac
' Hydra      010001000101010111110000OOOO??11 
'
' For this application we will check the status
' of P12..P13
'
' %00 - Demo/Protoboard
' %01 - Hydra
' %11 - Hybrid
'
' //////////////////////////////////////////////////////

CON

  _CLKMODE = RCSlow     ' Start prop in RCSlow mode internal crystal
  
  cols = 40
  rows = 15

  screensize = cols * rows
  lastrow = screensize - cols

  tv_count = 14

VAR

  Byte BasePin, Type, pad2, pad3

  
OBJ

  text : "tv_text"


PUB start | x , y

  HWDetect                                              ' Check harware type
  
  text.start(BasePin)                                   ' Start TV Terminal with relevant basepin

  Case Type
    0 :  text.str(string(13,"Parallax Demoboard - "))
    1 :  text.str(string(13,"Hydra Game Console - "))
    2 :  text.str(string(13,"Hybrid Development System - "))

  text.dec(clkfreq/1000000)                             ' Dispaly clock frequency in MHz
  text.str(string("MHz"))
      
  Repeat

Pub  HWDetect | HWPins

  clkset(%01101000,  12_000_000)                        ' Set internal oscillator to RCFast and set PLL to start
  waitcnt(cnt+120_000)                                  ' wait approx 10ms at 12mhz for PLL to 'warm up'
  
  HWPins := INA[12..13]                                 ' Check state of Pins 12-13

  CASE HWPins
    %00 : clkset( %01101111, 80_000_000 )               ' Demo Board   80MHz (5MHz PLLx16)  
          Basepin := 12
          Type    := 0      
    %01 : clkset( %01110110, 80_000_000 )               ' Hydra        80MHz (10MHz PLLx8)
          Basepin := 24
          Type    := 1
    %11 : clkset( %01101111, 96_000_000 )               ' Hybrid       96MHz (6MHz PLLx16)
          Basepin := 24
          Type    := 2

